/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'gl', {
	border: 'Amosar o bordo do marco',
	noUrl: 'Escriba o enderezo do iframe',
	scrolling: 'Activar as barras de desprazamento',
	title: 'Propiedades do iFrame',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
